from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSWPArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSDArchives_sos_pb2 as TSDArchives__sos__pb2
from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSSArchives_sos_pb2 as TSSArchives__sos__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSWPArchives_sos.proto',
  package='TSWP',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x16TSWPArchives_sos.proto\x12\x04TSWP\x1a\x15TSDArchives_sos.proto\x1a\x11TSPMessages.proto\x1a\x15TSSArchives_sos.proto\x1a\x12TSWPArchives.proto\"V\n\x1cSpecSetCharacterStyleArchive\x12\'\n\x0f\x63haracter_style\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\r\n\x05unset\x18\x02 \x02(\x08\"M\n\x15SpecSetColumnsArchive\x12%\n\x07\x63olumns\x18\x01 \x01(\x0b\x32\x14.TSWP.ColumnsArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"N\n\x15SpecSetDropCapArchive\x12&\n\x08\x64rop_cap\x18\x01 \x01(\x0b\x32\x14.TSWP.DropCapArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"}\n\x1aSpecSetFontFeaturesArchive\x12/\n\rfont_features\x18\x01 \x03(\x0b\x32\x18.TSWP.FontFeatureArchive\x12\x1f\n\x17\x66ont_features_undefined\x18\x02 \x01(\x08\x12\r\n\x05unset\x18\x03 \x02(\x08\"Z\n\x19SpecSetLineSpacingArchive\x12.\n\x0cline_spacing\x18\x01 \x01(\x0b\x32\x18.TSWP.LineSpacingArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"L\n\x17SpecSetListStyleArchive\x12\"\n\nlist_style\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\r\n\x05unset\x18\x02 \x02(\x08\"y\n SpecSetListStyleBoolArrayArchive\x12\x1d\n\x15list_style_bool_array\x18\x01 \x03(\x08\x12\'\n\x1flist_style_bool_array_undefined\x18\x02 \x01(\x08\x12\r\n\x05unset\x18\x03 \x02(\x08\"|\n!SpecSetListStyleFloatArrayArchive\x12\x1e\n\x16list_style_float_array\x18\x01 \x03(\x02\x12(\n list_style_float_array_undefined\x18\x02 \x01(\x08\x12\r\n\x05unset\x18\x03 \x02(\x08\"\xad\x01\n%SpecSetListStyleImageDataArrayArchive\x12\x46\n\x1blist_style_image_data_array\x18\x01 \x03(\x0b\x32!.TSWP.ListStyleArchive.LabelImage\x12-\n%list_style_image_data_array_undefined\x18\x02 \x01(\x08\x12\r\n\x05unset\x18\x03 \x02(\x08\"\xca\x01\n-SpecSetListStyleListLabelGeometryArrayArchive\x12R\n$list_style_list_label_geometry_array\x18\x01 \x03(\x0b\x32$.TSWP.ListStyleArchive.LabelGeometry\x12\x36\n.list_style_list_label_geometry_array_undefined\x18\x02 \x01(\x08\x12\r\n\x05unset\x18\x03 \x02(\x08\"\xba\x01\n)SpecSetListStyleListLabelTypeArrayArchive\x12J\n list_style_list_label_type_array\x18\x01 \x03(\x0e\x32 .TSWP.ListStyleArchive.LabelType\x12\x32\n*list_style_list_label_type_array_undefined\x18\x02 \x01(\x08\x12\r\n\x05unset\x18\x03 \x02(\x08\"\xbe\x01\n*SpecSetListStyleListNumberTypeArrayArchive\x12L\n!list_style_list_number_type_array\x18\x01 \x03(\x0e\x32!.TSWP.ListStyleArchive.NumberType\x12\x33\n+list_style_list_number_type_array_undefined\x18\x02 \x01(\x08\x12\r\n\x05unset\x18\x03 \x02(\x08\"\x7f\n\"SpecSetListStyleStringArrayArchive\x12\x1f\n\x17list_style_string_array\x18\x01 \x03(\t\x12)\n!list_style_string_array_undefined\x18\x02 \x01(\x08\x12\r\n\x05unset\x18\x03 \x02(\x08\"M\n\x15SpecSetPaddingArchive\x12%\n\x07padding\x18\x01 \x01(\x0b\x32\x14.TSWP.PaddingArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"V\n\x1cSpecSetParagraphStyleArchive\x12\'\n\x0fparagraph_style\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\r\n\x05unset\x18\x02 \x02(\x08\"J\n\x18SpecSetRuleOffsetArchive\x12\x1f\n\x0brule_offset\x18\x01 \x01(\x0b\x32\n.TSP.Point\x12\r\n\x05unset\x18\x02 \x02(\x08\"D\n\x12SpecSetTabsArchive\x12\x1f\n\x04tabs\x18\x01 \x01(\x0b\x32\x11.TSWP.TabsArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"a\n\x19SpecCharacterStyleArchive\x12\x44\n\x18spec_set_character_style\x18\x01 \x01(\x0b\x32\".TSWP.SpecSetCharacterStyleArchive\"K\n\x12SpecColumnsArchive\x12\x35\n\x10spec_set_columns\x18\x01 \x01(\x0b\x32\x1b.TSWP.SpecSetColumnsArchive\"L\n\x12SpecDropCapArchive\x12\x36\n\x11spec_set_drop_cap\x18\x01 \x01(\x0b\x32\x1b.TSWP.SpecSetDropCapArchive\"[\n\x17SpecFontFeaturesArchive\x12@\n\x16spec_set_font_features\x18\x01 \x01(\x0b\x32 .TSWP.SpecSetFontFeaturesArchive\"X\n\x16SpecLineSpacingArchive\x12>\n\x15spec_set_line_spacing\x18\x01 \x01(\x0b\x32\x1f.TSWP.SpecSetLineSpacingArchive\"R\n\x14SpecListStyleArchive\x12:\n\x13spec_set_list_style\x18\x01 \x01(\x0b\x32\x1d.TSWP.SpecSetListStyleArchive\"o\n\x1dSpecListStyleBoolArrayArchive\x12N\n\x1espec_set_list_style_bool_array\x18\x01 \x01(\x0b\x32&.TSWP.SpecSetListStyleBoolArrayArchive\"r\n\x1eSpecListStyleFloatArrayArchive\x12P\n\x1fspec_set_list_style_float_array\x18\x01 \x01(\x0b\x32\'.TSWP.SpecSetListStyleFloatArrayArchive\"\x7f\n\"SpecListStyleImageDataArrayArchive\x12Y\n$spec_set_list_style_image_data_array\x18\x01 \x01(\x0b\x32+.TSWP.SpecSetListStyleImageDataArrayArchive\"\x98\x01\n*SpecListStyleListLabelGeometryArrayArchive\x12j\n-spec_set_list_style_list_label_geometry_array\x18\x01 \x01(\x0b\x32\x33.TSWP.SpecSetListStyleListLabelGeometryArrayArchive\"\x8c\x01\n&SpecListStyleListLabelTypeArrayArchive\x12\x62\n)spec_set_list_style_list_label_type_array\x18\x01 \x01(\x0b\x32/.TSWP.SpecSetListStyleListLabelTypeArrayArchive\"\x8f\x01\n\'SpecListStyleListNumberTypeArrayArchive\x12\x64\n*spec_set_list_style_list_number_type_array\x18\x01 \x01(\x0b\x32\x30.TSWP.SpecSetListStyleListNumberTypeArrayArchive\"u\n\x1fSpecListStyleStringArrayArchive\x12R\n spec_set_list_style_string_array\x18\x01 \x01(\x0b\x32(.TSWP.SpecSetListStyleStringArrayArchive\"K\n\x12SpecPaddingArchive\x12\x35\n\x10spec_set_padding\x18\x01 \x01(\x0b\x32\x1b.TSWP.SpecSetPaddingArchive\"a\n\x19SpecParagraphStyleArchive\x12\x44\n\x18spec_set_paragraph_style\x18\x01 \x01(\x0b\x32\".TSWP.SpecSetParagraphStyleArchive\"U\n\x15SpecRuleOffsetArchive\x12<\n\x14spec_set_rule_offset\x18\x01 \x01(\x0b\x32\x1e.TSWP.SpecSetRuleOffsetArchive\"B\n\x0fSpecTabsArchive\x12/\n\rspec_set_tabs\x18\x01 \x01(\x0b\x32\x18.TSWP.SpecSetTabsArchive\"\x98\x14\n&CharacterStylePropertyChangeSetArchive\x12.\n\x0e\x62\x61seline_shift\x18\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12 \n\x18\x62\x61seline_shift_undefined\x18\x02 \x01(\x08\x12/\n\x0e\x63\x61pitalization\x18\x03 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12 \n\x18\x63\x61pitalization_undefined\x18\x04 \x01(\x08\x12\x37\n\x17\x63ompatibility_font_name\x18\x05 \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12)\n!compatibility_font_name_undefined\x18\x06 \x01(\x08\x12.\n\x0e\x65mphasis_marks\x18\x07 \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12 \n\x18\x65mphasis_marks_undefined\x18\x08 \x01(\x08\x12\"\n\x04\x62old\x18\t \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x16\n\x0e\x62old_undefined\x18\n \x01(\x08\x12$\n\x06italic\x18\x0b \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x18\n\x10italic_undefined\x18\x0c \x01(\x08\x12\x34\n\rfont_features\x18\r \x01(\x0b\x32\x1d.TSWP.SpecFontFeaturesArchive\x12\x1f\n\x17\x66ont_features_undefined\x18\x0e \x01(\x08\x12)\n\tfont_name\x18\x0f \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x1b\n\x13\x66ont_name_undefined\x18\x10 \x01(\x08\x12)\n\tfont_size\x18\x11 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1b\n\x13\x66ont_size_undefined\x18\x12 \x01(\x08\x12/\n\x0f\x66ont_size_delta\x18\x13 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12!\n\x19\x66ont_size_delta_undefined\x18\x14 \x01(\x08\x12\'\n\x07kerning\x18\x15 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x19\n\x11kerning_undefined\x18\x16 \x01(\x08\x12(\n\x08language\x18\x17 \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x1a\n\x12language_undefined\x18\x18 \x01(\x08\x12*\n\tligatures\x18\x19 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1b\n\x13ligatures_undefined\x18\x1a \x01(\x08\x12+\n\x0btext_shadow\x18\x1b \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1d\n\x15text_shadow_undefined\x18\x1c \x01(\x08\x12/\n\x10strikethru_color\x18\x1d \x01(\x0b\x32\x15.TSS.SpecColorArchive\x12\"\n\x1astrikethru_color_undefined\x18\x1e \x01(\x08\x12+\n\nstrikethru\x18\x1f \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1c\n\x14strikethru_undefined\x18  \x01(\x08\x12\x30\n\x10strikethru_width\x18! \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\"\n\x1astrikethru_width_undefined\x18\" \x01(\x08\x12,\n\x0bsuperscript\x18# \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1d\n\x15superscript_undefined\x18$ \x01(\x08\x12.\n\x0ftext_background\x18% \x01(\x0b\x32\x15.TSS.SpecColorArchive\x12!\n\x19text_background_undefined\x18& \x01(\x08\x12(\n\x08tracking\x18\' \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1a\n\x12tracking_undefined\x18( \x01(\x08\x12.\n\x0funderline_color\x18) \x01(\x0b\x32\x15.TSS.SpecColorArchive\x12!\n\x19underline_color_undefined\x18* \x01(\x08\x12*\n\tunderline\x18+ \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1b\n\x13underline_undefined\x18, \x01(\x08\x12/\n\x0funderline_width\x18- \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12!\n\x19underline_width_undefined\x18. \x01(\x08\x12-\n\x0fword_strikethru\x18/ \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12!\n\x19word_strikethru_undefined\x18\x30 \x01(\x08\x12,\n\x0eword_underline\x18\x31 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12 \n\x18word_underline_undefined\x18\x32 \x01(\x08\x12\x32\n\x11writing_direction\x18\x33 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1bwriting_direction_undefined\x18\x34 \x01(\x08\x12\x31\n\x13is_named_point_size\x18\x35 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12%\n\x1dis_named_point_size_undefined\x18\x36 \x01(\x08\x12=\n\x1f\x63\x61pitalization_uses_linguistics\x18\x37 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x31\n)capitalization_uses_linguistics_undefined\x18\x38 \x01(\x08\x12\x30\n\x10\x63haracter_stroke\x18\x39 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\"\n\x1a\x63haracter_stroke_undefined\x18: \x01(\x08\x12,\n\x0e\x63haracter_fill\x18; \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12 \n\x18\x63haracter_fill_undefined\x18< \x01(\x08\x12G\n)character_fill_should_fill_text_container\x18= \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12;\n3character_fill_should_fill_text_container_undefined\x18> \x01(\x08\"\xed\x05\n#ColumnStylePropertyChangeSetArchive\x12)\n\x07\x63olumns\x18\x01 \x01(\x0b\x32\x18.TSWP.SpecColumnsArchive\x12\x19\n\x11\x63olumns_undefined\x18\x02 \x01(\x08\x12(\n\ncontinuous\x18\x03 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1c\n\x14\x63ontinuous_undefined\x18\x04 \x01(\x08\x12)\n\x07margins\x18\x05 \x01(\x0b\x32\x18.TSWP.SpecPaddingArchive\x12\x19\n\x11margins_undefined\x18\x06 \x01(\x08\x12\x34\n\x14min_horizontal_inset\x18\x07 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12&\n\x1emin_horizontal_inset_undefined\x18\x08 \x01(\x08\x12)\n\x07padding\x18\t \x01(\x0b\x32\x18.TSWP.SpecPaddingArchive\x12\x19\n\x11padding_undefined\x18\n \x01(\x08\x12+\n\rshrink_to_fit\x18\x0b \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1f\n\x17shrink_to_fit_undefined\x18\x0c \x01(\x08\x12\x33\n\x12vertical_alignment\x18\r \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12$\n\x1cvertical_alignment_undefined\x18\x0e \x01(\x08\x12+\n\rvertical_text\x18\x0f \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1f\n\x17vertical_text_undefined\x18\x10 \x01(\x08\x12\x32\n\x11writing_direction\x18\x11 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1bwriting_direction_undefined\x18\x12 \x01(\x08\"\xbc\x02\n,DropCapSpecificStylePropertyChangeSetArchive\x12\x30\n\x0e\x64rop_cap_model\x18\x01 \x01(\x0b\x32\x18.TSWP.SpecDropCapArchive\x12 \n\x18\x64rop_cap_model_undefined\x18\x02 \x01(\x08\x12\x35\n\x15\x64rop_cap_shape_stroke\x18\x03 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\'\n\x1f\x64rop_cap_shape_stroke_undefined\x18\x04 \x01(\x08\x12\x31\n\x13\x64rop_cap_shape_fill\x18\x05 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12%\n\x1d\x64rop_cap_shape_fill_undefined\x18\x06 \x01(\x08\"\xf1\x02\n$DropCapStylePropertyChangeSetArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TSWP.CharacterStylePropertyChangeSetArchive\x12\x30\n\x0e\x64rop_cap_model\x18\x02 \x01(\x0b\x32\x18.TSWP.SpecDropCapArchive\x12 \n\x18\x64rop_cap_model_undefined\x18\x03 \x01(\x08\x12\x35\n\x15\x64rop_cap_shape_stroke\x18\x04 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\'\n\x1f\x64rop_cap_shape_stroke_undefined\x18\x05 \x01(\x08\x12\x31\n\x13\x64rop_cap_shape_fill\x18\x06 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12%\n\x1d\x64rop_cap_shape_fill_undefined\x18\x07 \x01(\x08\"\xa8\x0b\n!ListStylePropertyChangeSetArchive\x12.\n\x0flist_font_color\x18\x01 \x01(\x0b\x32\x15.TSS.SpecColorArchive\x12!\n\x19list_font_color_undefined\x18\x02 \x01(\x08\x12)\n\tfont_name\x18\x03 \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x1b\n\x13\x66ont_name_undefined\x18\x04 \x01(\x08\x12L\n\x1elist_classic_text_indent_array\x18\x05 \x01(\x0b\x32$.TSWP.SpecListStyleFloatArrayArchive\x12\x30\n(list_classic_text_indent_array_undefined\x18\x06 \x01(\x08\x12S\n\x19list_label_geometry_array\x18\x07 \x01(\x0b\x32\x30.TSWP.SpecListStyleListLabelGeometryArrayArchive\x12+\n#list_label_geometry_array_undefined\x18\x08 \x01(\x08\x12M\n\x1blist_label_image_data_array\x18\t \x01(\x0b\x32(.TSWP.SpecListStyleImageDataArrayArchive\x12-\n%list_label_image_data_array_undefined\x18\n \x01(\x08\x12\x45\n\x17list_label_indent_array\x18\x0b \x01(\x0b\x32$.TSWP.SpecListStyleFloatArrayArchive\x12)\n!list_label_indent_array_undefined\x18\x0c \x01(\x08\x12N\n\x17list_label_number_array\x18\r \x01(\x0b\x32-.TSWP.SpecListStyleListNumberTypeArrayArchive\x12)\n!list_label_number_array_undefined\x18\x0e \x01(\x08\x12K\n\x1elist_label_tiered_number_array\x18\x0f \x01(\x0b\x32#.TSWP.SpecListStyleBoolArrayArchive\x12\x30\n(list_label_tiered_number_array_undefined\x18\x10 \x01(\x08\x12+\n\x0btext_shadow\x18\x11 \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1d\n\x15text_shadow_undefined\x18\x12 \x01(\x08\x12\x46\n\x17list_label_string_array\x18\x13 \x01(\x0b\x32%.TSWP.SpecListStyleStringArrayArchive\x12)\n!list_label_string_array_undefined\x18\x14 \x01(\x08\x12\x44\n\x16list_text_indent_array\x18\x15 \x01(\x0b\x32$.TSWP.SpecListStyleFloatArrayArchive\x12(\n list_text_indent_array_undefined\x18\x16 \x01(\x08\x12K\n\x15list_label_type_array\x18\x17 \x01(\x0b\x32,.TSWP.SpecListStyleListLabelTypeArrayArchive\x12\'\n\x1flist_label_type_array_undefined\x18\x18 \x01(\x08\x12\x32\n\x11writing_direction\x18\x19 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1bwriting_direction_undefined\x18\x1a \x01(\x08\"\xd1\x11\n.ParagraphSpecificStylePropertyChangeSetArchive\x12*\n\talignment\x18\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1b\n\x13\x61lignment_undefined\x18\x02 \x01(\x08\x12+\n\x0b\x64\x65\x63imal_tab\x18\x03 \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x1d\n\x15\x64\x65\x63imal_tab_undefined\x18\x04 \x01(\x08\x12\x31\n\x11\x64\x65\x66\x61ult_tab_stops\x18\x05 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12#\n\x1b\x64\x65\x66\x61ult_tab_stops_undefined\x18\x06 \x01(\x08\x12-\n\x0eparagraph_fill\x18\x07 \x01(\x0b\x32\x15.TSS.SpecColorArchive\x12 \n\x18paragraph_fill_undefined\x18\x08 \x01(\x08\x12\x31\n\x11\x66irst_line_indent\x18\t \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12#\n\x1b\x66irst_line_indent_undefined\x18\n \x01(\x08\x12\x42\n\x19\x66ollowing_paragraph_style\x18\x0b \x01(\x0b\x32\x1f.TSWP.SpecParagraphStyleArchive\x12+\n#following_paragraph_style_undefined\x18\x0c \x01(\x08\x12\'\n\thyphenate\x18\r \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1b\n\x13hyphenate_undefined\x18\x0e \x01(\x08\x12\x36\n\x12initial_list_style\x18\x0f \x01(\x0b\x32\x1a.TSWP.SpecListStyleArchive\x12$\n\x1cinitial_list_style_undefined\x18\x10 \x01(\x08\x12\x31\n\x13keep_lines_together\x18\x11 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12%\n\x1dkeep_lines_together_undefined\x18\x12 \x01(\x08\x12,\n\x0ekeep_with_next\x18\x13 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12 \n\x18keep_with_next_undefined\x18\x14 \x01(\x08\x12+\n\x0bleft_indent\x18\x15 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1d\n\x15left_indent_undefined\x18\x16 \x01(\x08\x12\x32\n\x0cline_spacing\x18\x17 \x01(\x0b\x32\x1c.TSWP.SpecLineSpacingArchive\x12\x1e\n\x16line_spacing_undefined\x18\x18 \x01(\x08\x12.\n\routline_level\x18\x19 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1f\n\x17outline_level_undefined\x18\x1a \x01(\x08\x12\x33\n\x12outline_style_type\x18\x1b \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12$\n\x1coutline_style_type_undefined\x18\x1c \x01(\x08\x12/\n\x11page_break_before\x18\x1d \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12#\n\x1bpage_break_before_undefined\x18\x1e \x01(\x08\x12\x32\n\x11paragraph_borders\x18\x1f \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1bparagraph_borders_undefined\x18  \x01(\x08\x12:\n\x15paragraph_rule_offset\x18! \x01(\x0b\x32\x1b.TSWP.SpecRuleOffsetArchive\x12\'\n\x1fparagraph_rule_offset_undefined\x18\" \x01(\x08\x12\x34\n\x14paragraph_rule_width\x18# \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12&\n\x1eparagraph_rule_width_undefined\x18$ \x01(\x08\x12,\n\x0cright_indent\x18% \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1e\n\x16right_indent_undefined\x18& \x01(\x08\x12+\n\x0bspace_after\x18\' \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1d\n\x15space_after_undefined\x18( \x01(\x08\x12,\n\x0cspace_before\x18) \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1e\n\x16space_before_undefined\x18* \x01(\x08\x12\x30\n\x10paragraph_stroke\x18+ \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\"\n\x1aparagraph_stroke_undefined\x18, \x01(\x08\x12#\n\x04tabs\x18- \x01(\x0b\x32\x15.TSWP.SpecTabsArchive\x12\x16\n\x0etabs_undefined\x18. \x01(\x08\x12.\n\rwidow_control\x18/ \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1f\n\x17widow_control_undefined\x18\x30 \x01(\x08\x12\x34\n\x16show_in_bookmarks_list\x18\x31 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n show_in_bookmarks_list_undefined\x18\x32 \x01(\x08\x12\x35\n\x17show_in_t_o_c_navigator\x18\x33 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12)\n!show_in_t_o_c_navigator_undefined\x18\x34 \x01(\x08\"\x86\x12\n&ParagraphStylePropertyChangeSetArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TSWP.CharacterStylePropertyChangeSetArchive\x12*\n\talignment\x18\x02 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1b\n\x13\x61lignment_undefined\x18\x03 \x01(\x08\x12+\n\x0b\x64\x65\x63imal_tab\x18\x04 \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x1d\n\x15\x64\x65\x63imal_tab_undefined\x18\x05 \x01(\x08\x12\x31\n\x11\x64\x65\x66\x61ult_tab_stops\x18\x06 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12#\n\x1b\x64\x65\x66\x61ult_tab_stops_undefined\x18\x07 \x01(\x08\x12-\n\x0eparagraph_fill\x18\x08 \x01(\x0b\x32\x15.TSS.SpecColorArchive\x12 \n\x18paragraph_fill_undefined\x18\t \x01(\x08\x12\x31\n\x11\x66irst_line_indent\x18\n \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12#\n\x1b\x66irst_line_indent_undefined\x18\x0b \x01(\x08\x12\x42\n\x19\x66ollowing_paragraph_style\x18\x0c \x01(\x0b\x32\x1f.TSWP.SpecParagraphStyleArchive\x12+\n#following_paragraph_style_undefined\x18\r \x01(\x08\x12\'\n\thyphenate\x18\x0e \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1b\n\x13hyphenate_undefined\x18\x0f \x01(\x08\x12\x36\n\x12initial_list_style\x18\x10 \x01(\x0b\x32\x1a.TSWP.SpecListStyleArchive\x12$\n\x1cinitial_list_style_undefined\x18\x11 \x01(\x08\x12\x31\n\x13keep_lines_together\x18\x12 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12%\n\x1dkeep_lines_together_undefined\x18\x13 \x01(\x08\x12,\n\x0ekeep_with_next\x18\x14 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12 \n\x18keep_with_next_undefined\x18\x15 \x01(\x08\x12+\n\x0bleft_indent\x18\x16 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1d\n\x15left_indent_undefined\x18\x17 \x01(\x08\x12\x32\n\x0cline_spacing\x18\x18 \x01(\x0b\x32\x1c.TSWP.SpecLineSpacingArchive\x12\x1e\n\x16line_spacing_undefined\x18\x19 \x01(\x08\x12.\n\routline_level\x18\x1a \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1f\n\x17outline_level_undefined\x18\x1b \x01(\x08\x12\x33\n\x12outline_style_type\x18\x1c \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12$\n\x1coutline_style_type_undefined\x18\x1d \x01(\x08\x12/\n\x11page_break_before\x18\x1e \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12#\n\x1bpage_break_before_undefined\x18\x1f \x01(\x08\x12\x32\n\x11paragraph_borders\x18  \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1bparagraph_borders_undefined\x18! \x01(\x08\x12:\n\x15paragraph_rule_offset\x18\" \x01(\x0b\x32\x1b.TSWP.SpecRuleOffsetArchive\x12\'\n\x1fparagraph_rule_offset_undefined\x18# \x01(\x08\x12\x34\n\x14paragraph_rule_width\x18$ \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12&\n\x1eparagraph_rule_width_undefined\x18% \x01(\x08\x12,\n\x0cright_indent\x18& \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1e\n\x16right_indent_undefined\x18\' \x01(\x08\x12+\n\x0bspace_after\x18( \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1d\n\x15space_after_undefined\x18) \x01(\x08\x12,\n\x0cspace_before\x18* \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x1e\n\x16space_before_undefined\x18+ \x01(\x08\x12\x30\n\x10paragraph_stroke\x18, \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\"\n\x1aparagraph_stroke_undefined\x18- \x01(\x08\x12#\n\x04tabs\x18. \x01(\x0b\x32\x15.TSWP.SpecTabsArchive\x12\x16\n\x0etabs_undefined\x18/ \x01(\x08\x12.\n\rwidow_control\x18\x30 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1f\n\x17widow_control_undefined\x18\x31 \x01(\x08\x12\x34\n\x16show_in_bookmarks_list\x18\x32 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n show_in_bookmarks_list_undefined\x18\x33 \x01(\x08\x12\x35\n\x17show_in_t_o_c_navigator\x18\x34 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12)\n!show_in_t_o_c_navigator_undefined\x18\x35 \x01(\x08\"\xda\x04\n\"ShapeStylePropertyChangeSetArchive\x12:\n\x05super\x18\x01 \x02(\x0b\x32+.TSD.BaseShapeStylePropertyChangeSetArchive\x12)\n\x07\x63olumns\x18\x02 \x01(\x0b\x32\x18.TSWP.SpecColumnsArchive\x12\x19\n\x11\x63olumns_undefined\x18\x03 \x01(\x08\x12)\n\x07padding\x18\x04 \x01(\x0b\x32\x18.TSWP.SpecPaddingArchive\x12\x19\n\x11padding_undefined\x18\x05 \x01(\x08\x12\x30\n\x12shrink_text_to_fit\x18\x06 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12$\n\x1cshrink_text_to_fit_undefined\x18\x07 \x01(\x08\x12\x33\n\x12vertical_alignment\x18\x08 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12$\n\x1cvertical_alignment_undefined\x18\t \x01(\x08\x12+\n\rvertical_text\x18\n \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x1f\n\x17vertical_text_undefined\x18\x0b \x01(\x08\x12@\n\x17\x64\x65\x66\x61ult_paragraph_style\x18\x0c \x01(\x0b\x32\x1f.TSWP.SpecParagraphStyleArchive\x12)\n!default_paragraph_style_undefined\x18\r \x01(\x08\"\xa9\x02\n%TOCEntryStylePropertyChangeSetArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TSWP.ParagraphStylePropertyChangeSetArchive\x12\x32\n\x14toc_show_page_number\x18\x02 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12&\n\x1etoc_show_page_number_undefined\x18\x03 \x01(\x08\x12>\n\x15toc_page_number_style\x18\x04 \x01(\x0b\x32\x1f.TSWP.SpecCharacterStyleArchive\x12\'\n\x1ftoc_page_number_style_undefined\x18\x05 \x01(\x08\"\x8d\x02\n\x10StyleDiffArchive\x12\x1d\n\x05style\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12J\n\x14\x63haracter_change_set\x18\x02 \x01(\x0b\x32,.TSWP.CharacterStylePropertyChangeSetArchive\x12J\n\x14paragraph_change_set\x18\x03 \x01(\x0b\x32,.TSWP.ParagraphStylePropertyChangeSetArchive\x12\x42\n\x10shape_change_set\x18\x04 \x01(\x0b\x32(.TSWP.ShapeStylePropertyChangeSetArchive')
  ,
  dependencies=[TSDArchives__sos__pb2.DESCRIPTOR,TSPMessages__pb2.DESCRIPTOR,TSSArchives__sos__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,])




_SPECSETCHARACTERSTYLEARCHIVE = _descriptor.Descriptor(
  name='SpecSetCharacterStyleArchive',
  full_name='TSWP.SpecSetCharacterStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='character_style', full_name='TSWP.SpecSetCharacterStyleArchive.character_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetCharacterStyleArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=203,
)


_SPECSETCOLUMNSARCHIVE = _descriptor.Descriptor(
  name='SpecSetColumnsArchive',
  full_name='TSWP.SpecSetColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='TSWP.SpecSetColumnsArchive.columns', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetColumnsArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=282,
)


_SPECSETDROPCAPARCHIVE = _descriptor.Descriptor(
  name='SpecSetDropCapArchive',
  full_name='TSWP.SpecSetDropCapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='drop_cap', full_name='TSWP.SpecSetDropCapArchive.drop_cap', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetDropCapArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=362,
)


_SPECSETFONTFEATURESARCHIVE = _descriptor.Descriptor(
  name='SpecSetFontFeaturesArchive',
  full_name='TSWP.SpecSetFontFeaturesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='font_features', full_name='TSWP.SpecSetFontFeaturesArchive.font_features', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_features_undefined', full_name='TSWP.SpecSetFontFeaturesArchive.font_features_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetFontFeaturesArchive.unset', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=489,
)


_SPECSETLINESPACINGARCHIVE = _descriptor.Descriptor(
  name='SpecSetLineSpacingArchive',
  full_name='TSWP.SpecSetLineSpacingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_spacing', full_name='TSWP.SpecSetLineSpacingArchive.line_spacing', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetLineSpacingArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=581,
)


_SPECSETLISTSTYLEARCHIVE = _descriptor.Descriptor(
  name='SpecSetListStyleArchive',
  full_name='TSWP.SpecSetListStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style', full_name='TSWP.SpecSetListStyleArchive.list_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetListStyleArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=659,
)


_SPECSETLISTSTYLEBOOLARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecSetListStyleBoolArrayArchive',
  full_name='TSWP.SpecSetListStyleBoolArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style_bool_array', full_name='TSWP.SpecSetListStyleBoolArrayArchive.list_style_bool_array', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style_bool_array_undefined', full_name='TSWP.SpecSetListStyleBoolArrayArchive.list_style_bool_array_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetListStyleBoolArrayArchive.unset', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=661,
  serialized_end=782,
)


_SPECSETLISTSTYLEFLOATARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecSetListStyleFloatArrayArchive',
  full_name='TSWP.SpecSetListStyleFloatArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style_float_array', full_name='TSWP.SpecSetListStyleFloatArrayArchive.list_style_float_array', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style_float_array_undefined', full_name='TSWP.SpecSetListStyleFloatArrayArchive.list_style_float_array_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetListStyleFloatArrayArchive.unset', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=908,
)


_SPECSETLISTSTYLEIMAGEDATAARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecSetListStyleImageDataArrayArchive',
  full_name='TSWP.SpecSetListStyleImageDataArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style_image_data_array', full_name='TSWP.SpecSetListStyleImageDataArrayArchive.list_style_image_data_array', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style_image_data_array_undefined', full_name='TSWP.SpecSetListStyleImageDataArrayArchive.list_style_image_data_array_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetListStyleImageDataArrayArchive.unset', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=911,
  serialized_end=1084,
)


_SPECSETLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecSetListStyleListLabelGeometryArrayArchive',
  full_name='TSWP.SpecSetListStyleListLabelGeometryArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style_list_label_geometry_array', full_name='TSWP.SpecSetListStyleListLabelGeometryArrayArchive.list_style_list_label_geometry_array', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style_list_label_geometry_array_undefined', full_name='TSWP.SpecSetListStyleListLabelGeometryArrayArchive.list_style_list_label_geometry_array_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetListStyleListLabelGeometryArrayArchive.unset', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1087,
  serialized_end=1289,
)


_SPECSETLISTSTYLELISTLABELTYPEARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecSetListStyleListLabelTypeArrayArchive',
  full_name='TSWP.SpecSetListStyleListLabelTypeArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style_list_label_type_array', full_name='TSWP.SpecSetListStyleListLabelTypeArrayArchive.list_style_list_label_type_array', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style_list_label_type_array_undefined', full_name='TSWP.SpecSetListStyleListLabelTypeArrayArchive.list_style_list_label_type_array_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetListStyleListLabelTypeArrayArchive.unset', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1292,
  serialized_end=1478,
)


_SPECSETLISTSTYLELISTNUMBERTYPEARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecSetListStyleListNumberTypeArrayArchive',
  full_name='TSWP.SpecSetListStyleListNumberTypeArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style_list_number_type_array', full_name='TSWP.SpecSetListStyleListNumberTypeArrayArchive.list_style_list_number_type_array', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style_list_number_type_array_undefined', full_name='TSWP.SpecSetListStyleListNumberTypeArrayArchive.list_style_list_number_type_array_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetListStyleListNumberTypeArrayArchive.unset', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1481,
  serialized_end=1671,
)


_SPECSETLISTSTYLESTRINGARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecSetListStyleStringArrayArchive',
  full_name='TSWP.SpecSetListStyleStringArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style_string_array', full_name='TSWP.SpecSetListStyleStringArrayArchive.list_style_string_array', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style_string_array_undefined', full_name='TSWP.SpecSetListStyleStringArrayArchive.list_style_string_array_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetListStyleStringArrayArchive.unset', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1673,
  serialized_end=1800,
)


_SPECSETPADDINGARCHIVE = _descriptor.Descriptor(
  name='SpecSetPaddingArchive',
  full_name='TSWP.SpecSetPaddingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='padding', full_name='TSWP.SpecSetPaddingArchive.padding', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetPaddingArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1802,
  serialized_end=1879,
)


_SPECSETPARAGRAPHSTYLEARCHIVE = _descriptor.Descriptor(
  name='SpecSetParagraphStyleArchive',
  full_name='TSWP.SpecSetParagraphStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='paragraph_style', full_name='TSWP.SpecSetParagraphStyleArchive.paragraph_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetParagraphStyleArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1881,
  serialized_end=1967,
)


_SPECSETRULEOFFSETARCHIVE = _descriptor.Descriptor(
  name='SpecSetRuleOffsetArchive',
  full_name='TSWP.SpecSetRuleOffsetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_offset', full_name='TSWP.SpecSetRuleOffsetArchive.rule_offset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetRuleOffsetArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1969,
  serialized_end=2043,
)


_SPECSETTABSARCHIVE = _descriptor.Descriptor(
  name='SpecSetTabsArchive',
  full_name='TSWP.SpecSetTabsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tabs', full_name='TSWP.SpecSetTabsArchive.tabs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSWP.SpecSetTabsArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2045,
  serialized_end=2113,
)


_SPECCHARACTERSTYLEARCHIVE = _descriptor.Descriptor(
  name='SpecCharacterStyleArchive',
  full_name='TSWP.SpecCharacterStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_character_style', full_name='TSWP.SpecCharacterStyleArchive.spec_set_character_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2212,
)


_SPECCOLUMNSARCHIVE = _descriptor.Descriptor(
  name='SpecColumnsArchive',
  full_name='TSWP.SpecColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_columns', full_name='TSWP.SpecColumnsArchive.spec_set_columns', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2214,
  serialized_end=2289,
)


_SPECDROPCAPARCHIVE = _descriptor.Descriptor(
  name='SpecDropCapArchive',
  full_name='TSWP.SpecDropCapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_drop_cap', full_name='TSWP.SpecDropCapArchive.spec_set_drop_cap', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2291,
  serialized_end=2367,
)


_SPECFONTFEATURESARCHIVE = _descriptor.Descriptor(
  name='SpecFontFeaturesArchive',
  full_name='TSWP.SpecFontFeaturesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_font_features', full_name='TSWP.SpecFontFeaturesArchive.spec_set_font_features', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2369,
  serialized_end=2460,
)


_SPECLINESPACINGARCHIVE = _descriptor.Descriptor(
  name='SpecLineSpacingArchive',
  full_name='TSWP.SpecLineSpacingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_line_spacing', full_name='TSWP.SpecLineSpacingArchive.spec_set_line_spacing', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2462,
  serialized_end=2550,
)


_SPECLISTSTYLEARCHIVE = _descriptor.Descriptor(
  name='SpecListStyleArchive',
  full_name='TSWP.SpecListStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_list_style', full_name='TSWP.SpecListStyleArchive.spec_set_list_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2552,
  serialized_end=2634,
)


_SPECLISTSTYLEBOOLARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecListStyleBoolArrayArchive',
  full_name='TSWP.SpecListStyleBoolArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_list_style_bool_array', full_name='TSWP.SpecListStyleBoolArrayArchive.spec_set_list_style_bool_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2636,
  serialized_end=2747,
)


_SPECLISTSTYLEFLOATARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecListStyleFloatArrayArchive',
  full_name='TSWP.SpecListStyleFloatArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_list_style_float_array', full_name='TSWP.SpecListStyleFloatArrayArchive.spec_set_list_style_float_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2749,
  serialized_end=2863,
)


_SPECLISTSTYLEIMAGEDATAARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecListStyleImageDataArrayArchive',
  full_name='TSWP.SpecListStyleImageDataArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_list_style_image_data_array', full_name='TSWP.SpecListStyleImageDataArrayArchive.spec_set_list_style_image_data_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2865,
  serialized_end=2992,
)


_SPECLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecListStyleListLabelGeometryArrayArchive',
  full_name='TSWP.SpecListStyleListLabelGeometryArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_list_style_list_label_geometry_array', full_name='TSWP.SpecListStyleListLabelGeometryArrayArchive.spec_set_list_style_list_label_geometry_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2995,
  serialized_end=3147,
)


_SPECLISTSTYLELISTLABELTYPEARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecListStyleListLabelTypeArrayArchive',
  full_name='TSWP.SpecListStyleListLabelTypeArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_list_style_list_label_type_array', full_name='TSWP.SpecListStyleListLabelTypeArrayArchive.spec_set_list_style_list_label_type_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3150,
  serialized_end=3290,
)


_SPECLISTSTYLELISTNUMBERTYPEARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecListStyleListNumberTypeArrayArchive',
  full_name='TSWP.SpecListStyleListNumberTypeArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_list_style_list_number_type_array', full_name='TSWP.SpecListStyleListNumberTypeArrayArchive.spec_set_list_style_list_number_type_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3293,
  serialized_end=3436,
)


_SPECLISTSTYLESTRINGARRAYARCHIVE = _descriptor.Descriptor(
  name='SpecListStyleStringArrayArchive',
  full_name='TSWP.SpecListStyleStringArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_list_style_string_array', full_name='TSWP.SpecListStyleStringArrayArchive.spec_set_list_style_string_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3438,
  serialized_end=3555,
)


_SPECPADDINGARCHIVE = _descriptor.Descriptor(
  name='SpecPaddingArchive',
  full_name='TSWP.SpecPaddingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_padding', full_name='TSWP.SpecPaddingArchive.spec_set_padding', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3557,
  serialized_end=3632,
)


_SPECPARAGRAPHSTYLEARCHIVE = _descriptor.Descriptor(
  name='SpecParagraphStyleArchive',
  full_name='TSWP.SpecParagraphStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_paragraph_style', full_name='TSWP.SpecParagraphStyleArchive.spec_set_paragraph_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3634,
  serialized_end=3731,
)


_SPECRULEOFFSETARCHIVE = _descriptor.Descriptor(
  name='SpecRuleOffsetArchive',
  full_name='TSWP.SpecRuleOffsetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_rule_offset', full_name='TSWP.SpecRuleOffsetArchive.spec_set_rule_offset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3733,
  serialized_end=3818,
)


_SPECTABSARCHIVE = _descriptor.Descriptor(
  name='SpecTabsArchive',
  full_name='TSWP.SpecTabsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_tabs', full_name='TSWP.SpecTabsArchive.spec_set_tabs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3820,
  serialized_end=3886,
)


_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='CharacterStylePropertyChangeSetArchive',
  full_name='TSWP.CharacterStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='baseline_shift', full_name='TSWP.CharacterStylePropertyChangeSetArchive.baseline_shift', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseline_shift_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.baseline_shift_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capitalization', full_name='TSWP.CharacterStylePropertyChangeSetArchive.capitalization', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capitalization_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.capitalization_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compatibility_font_name', full_name='TSWP.CharacterStylePropertyChangeSetArchive.compatibility_font_name', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compatibility_font_name_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.compatibility_font_name_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='emphasis_marks', full_name='TSWP.CharacterStylePropertyChangeSetArchive.emphasis_marks', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='emphasis_marks_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.emphasis_marks_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bold', full_name='TSWP.CharacterStylePropertyChangeSetArchive.bold', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bold_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.bold_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='italic', full_name='TSWP.CharacterStylePropertyChangeSetArchive.italic', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='italic_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.italic_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_features', full_name='TSWP.CharacterStylePropertyChangeSetArchive.font_features', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_features_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.font_features_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name', full_name='TSWP.CharacterStylePropertyChangeSetArchive.font_name', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.font_name_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_size', full_name='TSWP.CharacterStylePropertyChangeSetArchive.font_size', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_size_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.font_size_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_size_delta', full_name='TSWP.CharacterStylePropertyChangeSetArchive.font_size_delta', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_size_delta_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.font_size_delta_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kerning', full_name='TSWP.CharacterStylePropertyChangeSetArchive.kerning', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kerning_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.kerning_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='TSWP.CharacterStylePropertyChangeSetArchive.language', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.language_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ligatures', full_name='TSWP.CharacterStylePropertyChangeSetArchive.ligatures', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ligatures_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.ligatures_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_shadow', full_name='TSWP.CharacterStylePropertyChangeSetArchive.text_shadow', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_shadow_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.text_shadow_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru_color', full_name='TSWP.CharacterStylePropertyChangeSetArchive.strikethru_color', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru_color_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.strikethru_color_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru', full_name='TSWP.CharacterStylePropertyChangeSetArchive.strikethru', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.strikethru_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru_width', full_name='TSWP.CharacterStylePropertyChangeSetArchive.strikethru_width', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru_width_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.strikethru_width_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='superscript', full_name='TSWP.CharacterStylePropertyChangeSetArchive.superscript', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='superscript_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.superscript_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_background', full_name='TSWP.CharacterStylePropertyChangeSetArchive.text_background', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_background_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.text_background_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking', full_name='TSWP.CharacterStylePropertyChangeSetArchive.tracking', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.tracking_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline_color', full_name='TSWP.CharacterStylePropertyChangeSetArchive.underline_color', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline_color_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.underline_color_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline', full_name='TSWP.CharacterStylePropertyChangeSetArchive.underline', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.underline_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline_width', full_name='TSWP.CharacterStylePropertyChangeSetArchive.underline_width', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline_width_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.underline_width_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='word_strikethru', full_name='TSWP.CharacterStylePropertyChangeSetArchive.word_strikethru', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='word_strikethru_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.word_strikethru_undefined', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='word_underline', full_name='TSWP.CharacterStylePropertyChangeSetArchive.word_underline', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='word_underline_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.word_underline_undefined', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TSWP.CharacterStylePropertyChangeSetArchive.writing_direction', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.writing_direction_undefined', index=51,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_named_point_size', full_name='TSWP.CharacterStylePropertyChangeSetArchive.is_named_point_size', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_named_point_size_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.is_named_point_size_undefined', index=53,
      number=54, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capitalization_uses_linguistics', full_name='TSWP.CharacterStylePropertyChangeSetArchive.capitalization_uses_linguistics', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capitalization_uses_linguistics_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.capitalization_uses_linguistics_undefined', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_stroke', full_name='TSWP.CharacterStylePropertyChangeSetArchive.character_stroke', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_stroke_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.character_stroke_undefined', index=57,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_fill', full_name='TSWP.CharacterStylePropertyChangeSetArchive.character_fill', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_fill_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.character_fill_undefined', index=59,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_fill_should_fill_text_container', full_name='TSWP.CharacterStylePropertyChangeSetArchive.character_fill_should_fill_text_container', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_fill_should_fill_text_container_undefined', full_name='TSWP.CharacterStylePropertyChangeSetArchive.character_fill_should_fill_text_container_undefined', index=61,
      number=62, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3889,
  serialized_end=6473,
)


_COLUMNSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ColumnStylePropertyChangeSetArchive',
  full_name='TSWP.ColumnStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='TSWP.ColumnStylePropertyChangeSetArchive.columns', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.columns_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuous', full_name='TSWP.ColumnStylePropertyChangeSetArchive.continuous', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuous_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.continuous_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margins', full_name='TSWP.ColumnStylePropertyChangeSetArchive.margins', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margins_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.margins_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_horizontal_inset', full_name='TSWP.ColumnStylePropertyChangeSetArchive.min_horizontal_inset', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_horizontal_inset_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.min_horizontal_inset_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='TSWP.ColumnStylePropertyChangeSetArchive.padding', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.padding_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shrink_to_fit', full_name='TSWP.ColumnStylePropertyChangeSetArchive.shrink_to_fit', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shrink_to_fit_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.shrink_to_fit_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment', full_name='TSWP.ColumnStylePropertyChangeSetArchive.vertical_alignment', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.vertical_alignment_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_text', full_name='TSWP.ColumnStylePropertyChangeSetArchive.vertical_text', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_text_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.vertical_text_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TSWP.ColumnStylePropertyChangeSetArchive.writing_direction', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction_undefined', full_name='TSWP.ColumnStylePropertyChangeSetArchive.writing_direction_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6476,
  serialized_end=7225,
)


_DROPCAPSPECIFICSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='DropCapSpecificStylePropertyChangeSetArchive',
  full_name='TSWP.DropCapSpecificStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='drop_cap_model', full_name='TSWP.DropCapSpecificStylePropertyChangeSetArchive.drop_cap_model', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_model_undefined', full_name='TSWP.DropCapSpecificStylePropertyChangeSetArchive.drop_cap_model_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_stroke', full_name='TSWP.DropCapSpecificStylePropertyChangeSetArchive.drop_cap_shape_stroke', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_stroke_undefined', full_name='TSWP.DropCapSpecificStylePropertyChangeSetArchive.drop_cap_shape_stroke_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_fill', full_name='TSWP.DropCapSpecificStylePropertyChangeSetArchive.drop_cap_shape_fill', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_fill_undefined', full_name='TSWP.DropCapSpecificStylePropertyChangeSetArchive.drop_cap_shape_fill_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7228,
  serialized_end=7544,
)


_DROPCAPSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='DropCapStylePropertyChangeSetArchive',
  full_name='TSWP.DropCapStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.DropCapStylePropertyChangeSetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_model', full_name='TSWP.DropCapStylePropertyChangeSetArchive.drop_cap_model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_model_undefined', full_name='TSWP.DropCapStylePropertyChangeSetArchive.drop_cap_model_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_stroke', full_name='TSWP.DropCapStylePropertyChangeSetArchive.drop_cap_shape_stroke', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_stroke_undefined', full_name='TSWP.DropCapStylePropertyChangeSetArchive.drop_cap_shape_stroke_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_fill', full_name='TSWP.DropCapStylePropertyChangeSetArchive.drop_cap_shape_fill', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_fill_undefined', full_name='TSWP.DropCapStylePropertyChangeSetArchive.drop_cap_shape_fill_undefined', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7547,
  serialized_end=7916,
)


_LISTSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ListStylePropertyChangeSetArchive',
  full_name='TSWP.ListStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_font_color', full_name='TSWP.ListStylePropertyChangeSetArchive.list_font_color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_font_color_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_font_color_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name', full_name='TSWP.ListStylePropertyChangeSetArchive.font_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.font_name_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_classic_text_indent_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_classic_text_indent_array', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_classic_text_indent_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_classic_text_indent_array_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_geometry_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_geometry_array', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_geometry_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_geometry_array_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_image_data_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_image_data_array', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_image_data_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_image_data_array_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_indent_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_indent_array', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_indent_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_indent_array_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_number_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_number_array', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_number_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_number_array_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_tiered_number_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_tiered_number_array', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_tiered_number_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_tiered_number_array_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_shadow', full_name='TSWP.ListStylePropertyChangeSetArchive.text_shadow', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_shadow_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.text_shadow_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_string_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_string_array', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_string_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_string_array_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_text_indent_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_text_indent_array', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_text_indent_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_text_indent_array_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_type_array', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_type_array', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_label_type_array_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.list_label_type_array_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TSWP.ListStylePropertyChangeSetArchive.writing_direction', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction_undefined', full_name='TSWP.ListStylePropertyChangeSetArchive.writing_direction_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7919,
  serialized_end=9367,
)


_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ParagraphSpecificStylePropertyChangeSetArchive',
  full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alignment', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.alignment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alignment_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.alignment_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_tab', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.decimal_tab', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_tab_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.decimal_tab_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_tab_stops', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.default_tab_stops', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_tab_stops_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.default_tab_stops_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_fill', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_fill', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_fill_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_fill_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_line_indent', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.first_line_indent', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_line_indent_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.first_line_indent_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following_paragraph_style', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.following_paragraph_style', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following_paragraph_style_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.following_paragraph_style_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hyphenate', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.hyphenate', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hyphenate_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.hyphenate_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_list_style', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.initial_list_style', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_list_style_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.initial_list_style_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_lines_together', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.keep_lines_together', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_lines_together_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.keep_lines_together_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_with_next', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.keep_with_next', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_with_next_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.keep_with_next_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_indent', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.left_indent', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_indent_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.left_indent_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_spacing', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.line_spacing', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_spacing_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.line_spacing_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_level', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.outline_level', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_level_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.outline_level_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_style_type', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.outline_style_type', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_style_type_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.outline_style_type_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_break_before', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.page_break_before', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_break_before_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.page_break_before_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_borders', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_borders', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_borders_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_borders_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_rule_offset', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_rule_offset', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_rule_offset_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_rule_offset_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_rule_width', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_rule_width', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_rule_width_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_rule_width_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_indent', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.right_indent', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_indent_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.right_indent_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_after', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.space_after', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_after_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.space_after_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_before', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.space_before', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_before_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.space_before_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_stroke', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_stroke', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_stroke_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.paragraph_stroke_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tabs', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.tabs', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tabs_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.tabs_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='widow_control', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.widow_control', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='widow_control_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.widow_control_undefined', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_bookmarks_list', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.show_in_bookmarks_list', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_bookmarks_list_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.show_in_bookmarks_list_undefined', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_t_o_c_navigator', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.show_in_t_o_c_navigator', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_t_o_c_navigator_undefined', full_name='TSWP.ParagraphSpecificStylePropertyChangeSetArchive.show_in_t_o_c_navigator_undefined', index=51,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9370,
  serialized_end=11627,
)


_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ParagraphStylePropertyChangeSetArchive',
  full_name='TSWP.ParagraphStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alignment', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.alignment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alignment_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.alignment_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_tab', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.decimal_tab', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_tab_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.decimal_tab_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_tab_stops', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.default_tab_stops', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_tab_stops_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.default_tab_stops_undefined', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_fill', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_fill', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_fill_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_fill_undefined', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_line_indent', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.first_line_indent', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_line_indent_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.first_line_indent_undefined', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following_paragraph_style', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.following_paragraph_style', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following_paragraph_style_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.following_paragraph_style_undefined', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hyphenate', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.hyphenate', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hyphenate_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.hyphenate_undefined', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_list_style', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.initial_list_style', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_list_style_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.initial_list_style_undefined', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_lines_together', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.keep_lines_together', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_lines_together_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.keep_lines_together_undefined', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_with_next', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.keep_with_next', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_with_next_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.keep_with_next_undefined', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_indent', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.left_indent', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_indent_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.left_indent_undefined', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_spacing', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.line_spacing', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_spacing_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.line_spacing_undefined', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_level', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.outline_level', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_level_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.outline_level_undefined', index=26,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_style_type', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.outline_style_type', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_style_type_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.outline_style_type_undefined', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_break_before', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.page_break_before', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_break_before_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.page_break_before_undefined', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_borders', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_borders', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_borders_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_borders_undefined', index=32,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_rule_offset', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_rule_offset', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_rule_offset_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_rule_offset_undefined', index=34,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_rule_width', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_rule_width', index=35,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_rule_width_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_rule_width_undefined', index=36,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_indent', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.right_indent', index=37,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_indent_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.right_indent_undefined', index=38,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_after', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.space_after', index=39,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_after_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.space_after_undefined', index=40,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_before', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.space_before', index=41,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_before_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.space_before_undefined', index=42,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_stroke', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_stroke', index=43,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_stroke_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.paragraph_stroke_undefined', index=44,
      number=45, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tabs', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.tabs', index=45,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tabs_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.tabs_undefined', index=46,
      number=47, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='widow_control', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.widow_control', index=47,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='widow_control_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.widow_control_undefined', index=48,
      number=49, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_bookmarks_list', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.show_in_bookmarks_list', index=49,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_bookmarks_list_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.show_in_bookmarks_list_undefined', index=50,
      number=51, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_t_o_c_navigator', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.show_in_t_o_c_navigator', index=51,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_t_o_c_navigator_undefined', full_name='TSWP.ParagraphStylePropertyChangeSetArchive.show_in_t_o_c_navigator_undefined', index=52,
      number=53, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11630,
  serialized_end=13940,
)


_SHAPESTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ShapeStylePropertyChangeSetArchive',
  full_name='TSWP.ShapeStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ShapeStylePropertyChangeSetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns', full_name='TSWP.ShapeStylePropertyChangeSetArchive.columns', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns_undefined', full_name='TSWP.ShapeStylePropertyChangeSetArchive.columns_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='TSWP.ShapeStylePropertyChangeSetArchive.padding', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding_undefined', full_name='TSWP.ShapeStylePropertyChangeSetArchive.padding_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shrink_text_to_fit', full_name='TSWP.ShapeStylePropertyChangeSetArchive.shrink_text_to_fit', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shrink_text_to_fit_undefined', full_name='TSWP.ShapeStylePropertyChangeSetArchive.shrink_text_to_fit_undefined', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment', full_name='TSWP.ShapeStylePropertyChangeSetArchive.vertical_alignment', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment_undefined', full_name='TSWP.ShapeStylePropertyChangeSetArchive.vertical_alignment_undefined', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_text', full_name='TSWP.ShapeStylePropertyChangeSetArchive.vertical_text', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_text_undefined', full_name='TSWP.ShapeStylePropertyChangeSetArchive.vertical_text_undefined', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_paragraph_style', full_name='TSWP.ShapeStylePropertyChangeSetArchive.default_paragraph_style', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_paragraph_style_undefined', full_name='TSWP.ShapeStylePropertyChangeSetArchive.default_paragraph_style_undefined', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13943,
  serialized_end=14545,
)


_TOCENTRYSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='TOCEntryStylePropertyChangeSetArchive',
  full_name='TSWP.TOCEntryStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TOCEntryStylePropertyChangeSetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_show_page_number', full_name='TSWP.TOCEntryStylePropertyChangeSetArchive.toc_show_page_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_show_page_number_undefined', full_name='TSWP.TOCEntryStylePropertyChangeSetArchive.toc_show_page_number_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_page_number_style', full_name='TSWP.TOCEntryStylePropertyChangeSetArchive.toc_page_number_style', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_page_number_style_undefined', full_name='TSWP.TOCEntryStylePropertyChangeSetArchive.toc_page_number_style_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14548,
  serialized_end=14845,
)


_STYLEDIFFARCHIVE = _descriptor.Descriptor(
  name='StyleDiffArchive',
  full_name='TSWP.StyleDiffArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='style', full_name='TSWP.StyleDiffArchive.style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_change_set', full_name='TSWP.StyleDiffArchive.character_change_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_change_set', full_name='TSWP.StyleDiffArchive.paragraph_change_set', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape_change_set', full_name='TSWP.StyleDiffArchive.shape_change_set', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14848,
  serialized_end=15117,
)

_SPECSETCHARACTERSTYLEARCHIVE.fields_by_name['character_style'].message_type = TSPMessages__pb2._REFERENCE
_SPECSETCOLUMNSARCHIVE.fields_by_name['columns'].message_type = TSWPArchives__pb2._COLUMNSARCHIVE
_SPECSETDROPCAPARCHIVE.fields_by_name['drop_cap'].message_type = TSWPArchives__pb2._DROPCAPARCHIVE
_SPECSETFONTFEATURESARCHIVE.fields_by_name['font_features'].message_type = TSWPArchives__pb2._FONTFEATUREARCHIVE
_SPECSETLINESPACINGARCHIVE.fields_by_name['line_spacing'].message_type = TSWPArchives__pb2._LINESPACINGARCHIVE
_SPECSETLISTSTYLEARCHIVE.fields_by_name['list_style'].message_type = TSPMessages__pb2._REFERENCE
_SPECSETLISTSTYLEIMAGEDATAARRAYARCHIVE.fields_by_name['list_style_image_data_array'].message_type = TSWPArchives__pb2._LISTSTYLEARCHIVE_LABELIMAGE
_SPECSETLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE.fields_by_name['list_style_list_label_geometry_array'].message_type = TSWPArchives__pb2._LISTSTYLEARCHIVE_LABELGEOMETRY
_SPECSETLISTSTYLELISTLABELTYPEARRAYARCHIVE.fields_by_name['list_style_list_label_type_array'].enum_type = TSWPArchives__pb2._LISTSTYLEARCHIVE_LABELTYPE
_SPECSETLISTSTYLELISTNUMBERTYPEARRAYARCHIVE.fields_by_name['list_style_list_number_type_array'].enum_type = TSWPArchives__pb2._LISTSTYLEARCHIVE_NUMBERTYPE
_SPECSETPADDINGARCHIVE.fields_by_name['padding'].message_type = TSWPArchives__pb2._PADDINGARCHIVE
_SPECSETPARAGRAPHSTYLEARCHIVE.fields_by_name['paragraph_style'].message_type = TSPMessages__pb2._REFERENCE
_SPECSETRULEOFFSETARCHIVE.fields_by_name['rule_offset'].message_type = TSPMessages__pb2._POINT
_SPECSETTABSARCHIVE.fields_by_name['tabs'].message_type = TSWPArchives__pb2._TABSARCHIVE
_SPECCHARACTERSTYLEARCHIVE.fields_by_name['spec_set_character_style'].message_type = _SPECSETCHARACTERSTYLEARCHIVE
_SPECCOLUMNSARCHIVE.fields_by_name['spec_set_columns'].message_type = _SPECSETCOLUMNSARCHIVE
_SPECDROPCAPARCHIVE.fields_by_name['spec_set_drop_cap'].message_type = _SPECSETDROPCAPARCHIVE
_SPECFONTFEATURESARCHIVE.fields_by_name['spec_set_font_features'].message_type = _SPECSETFONTFEATURESARCHIVE
_SPECLINESPACINGARCHIVE.fields_by_name['spec_set_line_spacing'].message_type = _SPECSETLINESPACINGARCHIVE
_SPECLISTSTYLEARCHIVE.fields_by_name['spec_set_list_style'].message_type = _SPECSETLISTSTYLEARCHIVE
_SPECLISTSTYLEBOOLARRAYARCHIVE.fields_by_name['spec_set_list_style_bool_array'].message_type = _SPECSETLISTSTYLEBOOLARRAYARCHIVE
_SPECLISTSTYLEFLOATARRAYARCHIVE.fields_by_name['spec_set_list_style_float_array'].message_type = _SPECSETLISTSTYLEFLOATARRAYARCHIVE
_SPECLISTSTYLEIMAGEDATAARRAYARCHIVE.fields_by_name['spec_set_list_style_image_data_array'].message_type = _SPECSETLISTSTYLEIMAGEDATAARRAYARCHIVE
_SPECLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE.fields_by_name['spec_set_list_style_list_label_geometry_array'].message_type = _SPECSETLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE
_SPECLISTSTYLELISTLABELTYPEARRAYARCHIVE.fields_by_name['spec_set_list_style_list_label_type_array'].message_type = _SPECSETLISTSTYLELISTLABELTYPEARRAYARCHIVE
_SPECLISTSTYLELISTNUMBERTYPEARRAYARCHIVE.fields_by_name['spec_set_list_style_list_number_type_array'].message_type = _SPECSETLISTSTYLELISTNUMBERTYPEARRAYARCHIVE
_SPECLISTSTYLESTRINGARRAYARCHIVE.fields_by_name['spec_set_list_style_string_array'].message_type = _SPECSETLISTSTYLESTRINGARRAYARCHIVE
_SPECPADDINGARCHIVE.fields_by_name['spec_set_padding'].message_type = _SPECSETPADDINGARCHIVE
_SPECPARAGRAPHSTYLEARCHIVE.fields_by_name['spec_set_paragraph_style'].message_type = _SPECSETPARAGRAPHSTYLEARCHIVE
_SPECRULEOFFSETARCHIVE.fields_by_name['spec_set_rule_offset'].message_type = _SPECSETRULEOFFSETARCHIVE
_SPECTABSARCHIVE.fields_by_name['spec_set_tabs'].message_type = _SPECSETTABSARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['baseline_shift'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['capitalization'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['compatibility_font_name'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['emphasis_marks'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bold'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['italic'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['font_features'].message_type = _SPECFONTFEATURESARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['font_name'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['font_size'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['font_size_delta'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['kerning'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['language'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['ligatures'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['text_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['strikethru_color'].message_type = TSSArchives__sos__pb2._SPECCOLORARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['strikethru'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['strikethru_width'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['superscript'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['text_background'].message_type = TSSArchives__sos__pb2._SPECCOLORARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['tracking'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['underline_color'].message_type = TSSArchives__sos__pb2._SPECCOLORARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['underline'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['underline_width'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['word_strikethru'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['word_underline'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['writing_direction'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['is_named_point_size'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['capitalization_uses_linguistics'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['character_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['character_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARACTERSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['character_fill_should_fill_text_container'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['columns'].message_type = _SPECCOLUMNSARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['continuous'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['margins'].message_type = _SPECPADDINGARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['min_horizontal_inset'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['padding'].message_type = _SPECPADDINGARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['shrink_to_fit'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['vertical_alignment'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['vertical_text'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_COLUMNSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['writing_direction'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_DROPCAPSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['drop_cap_model'].message_type = _SPECDROPCAPARCHIVE
_DROPCAPSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['drop_cap_shape_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_DROPCAPSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['drop_cap_shape_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_DROPCAPSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['super'].message_type = _CHARACTERSTYLEPROPERTYCHANGESETARCHIVE
_DROPCAPSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['drop_cap_model'].message_type = _SPECDROPCAPARCHIVE
_DROPCAPSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['drop_cap_shape_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_DROPCAPSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['drop_cap_shape_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_font_color'].message_type = TSSArchives__sos__pb2._SPECCOLORARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['font_name'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_classic_text_indent_array'].message_type = _SPECLISTSTYLEFLOATARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_label_geometry_array'].message_type = _SPECLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_label_image_data_array'].message_type = _SPECLISTSTYLEIMAGEDATAARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_label_indent_array'].message_type = _SPECLISTSTYLEFLOATARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_label_number_array'].message_type = _SPECLISTSTYLELISTNUMBERTYPEARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_label_tiered_number_array'].message_type = _SPECLISTSTYLEBOOLARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['text_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_label_string_array'].message_type = _SPECLISTSTYLESTRINGARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_text_indent_array'].message_type = _SPECLISTSTYLEFLOATARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['list_label_type_array'].message_type = _SPECLISTSTYLELISTLABELTYPEARRAYARCHIVE
_LISTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['writing_direction'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['alignment'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['decimal_tab'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_tab_stops'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_fill'].message_type = TSSArchives__sos__pb2._SPECCOLORARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['first_line_indent'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['following_paragraph_style'].message_type = _SPECPARAGRAPHSTYLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['hyphenate'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['initial_list_style'].message_type = _SPECLISTSTYLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['keep_lines_together'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['keep_with_next'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['left_indent'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_spacing'].message_type = _SPECLINESPACINGARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['outline_level'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['outline_style_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['page_break_before'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_borders'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_rule_offset'].message_type = _SPECRULEOFFSETARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_rule_width'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['right_indent'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['space_after'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['space_before'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['tabs'].message_type = _SPECTABSARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['widow_control'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['show_in_bookmarks_list'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['show_in_t_o_c_navigator'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['super'].message_type = _CHARACTERSTYLEPROPERTYCHANGESETARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['alignment'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['decimal_tab'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_tab_stops'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_fill'].message_type = TSSArchives__sos__pb2._SPECCOLORARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['first_line_indent'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['following_paragraph_style'].message_type = _SPECPARAGRAPHSTYLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['hyphenate'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['initial_list_style'].message_type = _SPECLISTSTYLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['keep_lines_together'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['keep_with_next'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['left_indent'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_spacing'].message_type = _SPECLINESPACINGARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['outline_level'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['outline_style_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['page_break_before'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_borders'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_rule_offset'].message_type = _SPECRULEOFFSETARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_rule_width'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['right_indent'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['space_after'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['space_before'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['paragraph_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['tabs'].message_type = _SPECTABSARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['widow_control'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['show_in_bookmarks_list'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['show_in_t_o_c_navigator'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_SHAPESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['super'].message_type = TSDArchives__sos__pb2._BASESHAPESTYLEPROPERTYCHANGESETARCHIVE
_SHAPESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['columns'].message_type = _SPECCOLUMNSARCHIVE
_SHAPESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['padding'].message_type = _SPECPADDINGARCHIVE
_SHAPESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['shrink_text_to_fit'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_SHAPESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['vertical_alignment'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_SHAPESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['vertical_text'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_SHAPESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_paragraph_style'].message_type = _SPECPARAGRAPHSTYLEARCHIVE
_TOCENTRYSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['super'].message_type = _PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE
_TOCENTRYSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['toc_show_page_number'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_TOCENTRYSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['toc_page_number_style'].message_type = _SPECCHARACTERSTYLEARCHIVE
_STYLEDIFFARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_STYLEDIFFARCHIVE.fields_by_name['character_change_set'].message_type = _CHARACTERSTYLEPROPERTYCHANGESETARCHIVE
_STYLEDIFFARCHIVE.fields_by_name['paragraph_change_set'].message_type = _PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE
_STYLEDIFFARCHIVE.fields_by_name['shape_change_set'].message_type = _SHAPESTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetCharacterStyleArchive'] = _SPECSETCHARACTERSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetColumnsArchive'] = _SPECSETCOLUMNSARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetDropCapArchive'] = _SPECSETDROPCAPARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetFontFeaturesArchive'] = _SPECSETFONTFEATURESARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetLineSpacingArchive'] = _SPECSETLINESPACINGARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetListStyleArchive'] = _SPECSETLISTSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetListStyleBoolArrayArchive'] = _SPECSETLISTSTYLEBOOLARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetListStyleFloatArrayArchive'] = _SPECSETLISTSTYLEFLOATARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetListStyleImageDataArrayArchive'] = _SPECSETLISTSTYLEIMAGEDATAARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetListStyleListLabelGeometryArrayArchive'] = _SPECSETLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetListStyleListLabelTypeArrayArchive'] = _SPECSETLISTSTYLELISTLABELTYPEARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetListStyleListNumberTypeArrayArchive'] = _SPECSETLISTSTYLELISTNUMBERTYPEARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetListStyleStringArrayArchive'] = _SPECSETLISTSTYLESTRINGARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetPaddingArchive'] = _SPECSETPADDINGARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetParagraphStyleArchive'] = _SPECSETPARAGRAPHSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetRuleOffsetArchive'] = _SPECSETRULEOFFSETARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetTabsArchive'] = _SPECSETTABSARCHIVE
DESCRIPTOR.message_types_by_name['SpecCharacterStyleArchive'] = _SPECCHARACTERSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecColumnsArchive'] = _SPECCOLUMNSARCHIVE
DESCRIPTOR.message_types_by_name['SpecDropCapArchive'] = _SPECDROPCAPARCHIVE
DESCRIPTOR.message_types_by_name['SpecFontFeaturesArchive'] = _SPECFONTFEATURESARCHIVE
DESCRIPTOR.message_types_by_name['SpecLineSpacingArchive'] = _SPECLINESPACINGARCHIVE
DESCRIPTOR.message_types_by_name['SpecListStyleArchive'] = _SPECLISTSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecListStyleBoolArrayArchive'] = _SPECLISTSTYLEBOOLARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecListStyleFloatArrayArchive'] = _SPECLISTSTYLEFLOATARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecListStyleImageDataArrayArchive'] = _SPECLISTSTYLEIMAGEDATAARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecListStyleListLabelGeometryArrayArchive'] = _SPECLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecListStyleListLabelTypeArrayArchive'] = _SPECLISTSTYLELISTLABELTYPEARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecListStyleListNumberTypeArrayArchive'] = _SPECLISTSTYLELISTNUMBERTYPEARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecListStyleStringArrayArchive'] = _SPECLISTSTYLESTRINGARRAYARCHIVE
DESCRIPTOR.message_types_by_name['SpecPaddingArchive'] = _SPECPADDINGARCHIVE
DESCRIPTOR.message_types_by_name['SpecParagraphStyleArchive'] = _SPECPARAGRAPHSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecRuleOffsetArchive'] = _SPECRULEOFFSETARCHIVE
DESCRIPTOR.message_types_by_name['SpecTabsArchive'] = _SPECTABSARCHIVE
DESCRIPTOR.message_types_by_name['CharacterStylePropertyChangeSetArchive'] = _CHARACTERSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ColumnStylePropertyChangeSetArchive'] = _COLUMNSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['DropCapSpecificStylePropertyChangeSetArchive'] = _DROPCAPSPECIFICSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['DropCapStylePropertyChangeSetArchive'] = _DROPCAPSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ListStylePropertyChangeSetArchive'] = _LISTSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ParagraphSpecificStylePropertyChangeSetArchive'] = _PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ParagraphStylePropertyChangeSetArchive'] = _PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ShapeStylePropertyChangeSetArchive'] = _SHAPESTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['TOCEntryStylePropertyChangeSetArchive'] = _TOCENTRYSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['StyleDiffArchive'] = _STYLEDIFFARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpecSetCharacterStyleArchive = _reflection.GeneratedProtocolMessageType('SpecSetCharacterStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETCHARACTERSTYLEARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetCharacterStyleArchive)
  ))
_sym_db.RegisterMessage(SpecSetCharacterStyleArchive)

SpecSetColumnsArchive = _reflection.GeneratedProtocolMessageType('SpecSetColumnsArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETCOLUMNSARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetColumnsArchive)
  ))
_sym_db.RegisterMessage(SpecSetColumnsArchive)

SpecSetDropCapArchive = _reflection.GeneratedProtocolMessageType('SpecSetDropCapArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETDROPCAPARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetDropCapArchive)
  ))
_sym_db.RegisterMessage(SpecSetDropCapArchive)

SpecSetFontFeaturesArchive = _reflection.GeneratedProtocolMessageType('SpecSetFontFeaturesArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETFONTFEATURESARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetFontFeaturesArchive)
  ))
_sym_db.RegisterMessage(SpecSetFontFeaturesArchive)

SpecSetLineSpacingArchive = _reflection.GeneratedProtocolMessageType('SpecSetLineSpacingArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLINESPACINGARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetLineSpacingArchive)
  ))
_sym_db.RegisterMessage(SpecSetLineSpacingArchive)

SpecSetListStyleArchive = _reflection.GeneratedProtocolMessageType('SpecSetListStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLISTSTYLEARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetListStyleArchive)
  ))
_sym_db.RegisterMessage(SpecSetListStyleArchive)

SpecSetListStyleBoolArrayArchive = _reflection.GeneratedProtocolMessageType('SpecSetListStyleBoolArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLISTSTYLEBOOLARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetListStyleBoolArrayArchive)
  ))
_sym_db.RegisterMessage(SpecSetListStyleBoolArrayArchive)

SpecSetListStyleFloatArrayArchive = _reflection.GeneratedProtocolMessageType('SpecSetListStyleFloatArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLISTSTYLEFLOATARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetListStyleFloatArrayArchive)
  ))
_sym_db.RegisterMessage(SpecSetListStyleFloatArrayArchive)

SpecSetListStyleImageDataArrayArchive = _reflection.GeneratedProtocolMessageType('SpecSetListStyleImageDataArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLISTSTYLEIMAGEDATAARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetListStyleImageDataArrayArchive)
  ))
_sym_db.RegisterMessage(SpecSetListStyleImageDataArrayArchive)

SpecSetListStyleListLabelGeometryArrayArchive = _reflection.GeneratedProtocolMessageType('SpecSetListStyleListLabelGeometryArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetListStyleListLabelGeometryArrayArchive)
  ))
_sym_db.RegisterMessage(SpecSetListStyleListLabelGeometryArrayArchive)

SpecSetListStyleListLabelTypeArrayArchive = _reflection.GeneratedProtocolMessageType('SpecSetListStyleListLabelTypeArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLISTSTYLELISTLABELTYPEARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetListStyleListLabelTypeArrayArchive)
  ))
_sym_db.RegisterMessage(SpecSetListStyleListLabelTypeArrayArchive)

SpecSetListStyleListNumberTypeArrayArchive = _reflection.GeneratedProtocolMessageType('SpecSetListStyleListNumberTypeArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLISTSTYLELISTNUMBERTYPEARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetListStyleListNumberTypeArrayArchive)
  ))
_sym_db.RegisterMessage(SpecSetListStyleListNumberTypeArrayArchive)

SpecSetListStyleStringArrayArchive = _reflection.GeneratedProtocolMessageType('SpecSetListStyleStringArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETLISTSTYLESTRINGARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetListStyleStringArrayArchive)
  ))
_sym_db.RegisterMessage(SpecSetListStyleStringArrayArchive)

SpecSetPaddingArchive = _reflection.GeneratedProtocolMessageType('SpecSetPaddingArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETPADDINGARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetPaddingArchive)
  ))
_sym_db.RegisterMessage(SpecSetPaddingArchive)

SpecSetParagraphStyleArchive = _reflection.GeneratedProtocolMessageType('SpecSetParagraphStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETPARAGRAPHSTYLEARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetParagraphStyleArchive)
  ))
_sym_db.RegisterMessage(SpecSetParagraphStyleArchive)

SpecSetRuleOffsetArchive = _reflection.GeneratedProtocolMessageType('SpecSetRuleOffsetArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETRULEOFFSETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetRuleOffsetArchive)
  ))
_sym_db.RegisterMessage(SpecSetRuleOffsetArchive)

SpecSetTabsArchive = _reflection.GeneratedProtocolMessageType('SpecSetTabsArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETTABSARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecSetTabsArchive)
  ))
_sym_db.RegisterMessage(SpecSetTabsArchive)

SpecCharacterStyleArchive = _reflection.GeneratedProtocolMessageType('SpecCharacterStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCHARACTERSTYLEARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecCharacterStyleArchive)
  ))
_sym_db.RegisterMessage(SpecCharacterStyleArchive)

SpecColumnsArchive = _reflection.GeneratedProtocolMessageType('SpecColumnsArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCOLUMNSARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecColumnsArchive)
  ))
_sym_db.RegisterMessage(SpecColumnsArchive)

SpecDropCapArchive = _reflection.GeneratedProtocolMessageType('SpecDropCapArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECDROPCAPARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecDropCapArchive)
  ))
_sym_db.RegisterMessage(SpecDropCapArchive)

SpecFontFeaturesArchive = _reflection.GeneratedProtocolMessageType('SpecFontFeaturesArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECFONTFEATURESARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecFontFeaturesArchive)
  ))
_sym_db.RegisterMessage(SpecFontFeaturesArchive)

SpecLineSpacingArchive = _reflection.GeneratedProtocolMessageType('SpecLineSpacingArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLINESPACINGARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecLineSpacingArchive)
  ))
_sym_db.RegisterMessage(SpecLineSpacingArchive)

SpecListStyleArchive = _reflection.GeneratedProtocolMessageType('SpecListStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLISTSTYLEARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecListStyleArchive)
  ))
_sym_db.RegisterMessage(SpecListStyleArchive)

SpecListStyleBoolArrayArchive = _reflection.GeneratedProtocolMessageType('SpecListStyleBoolArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLISTSTYLEBOOLARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecListStyleBoolArrayArchive)
  ))
_sym_db.RegisterMessage(SpecListStyleBoolArrayArchive)

SpecListStyleFloatArrayArchive = _reflection.GeneratedProtocolMessageType('SpecListStyleFloatArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLISTSTYLEFLOATARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecListStyleFloatArrayArchive)
  ))
_sym_db.RegisterMessage(SpecListStyleFloatArrayArchive)

SpecListStyleImageDataArrayArchive = _reflection.GeneratedProtocolMessageType('SpecListStyleImageDataArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLISTSTYLEIMAGEDATAARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecListStyleImageDataArrayArchive)
  ))
_sym_db.RegisterMessage(SpecListStyleImageDataArrayArchive)

SpecListStyleListLabelGeometryArrayArchive = _reflection.GeneratedProtocolMessageType('SpecListStyleListLabelGeometryArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLISTSTYLELISTLABELGEOMETRYARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecListStyleListLabelGeometryArrayArchive)
  ))
_sym_db.RegisterMessage(SpecListStyleListLabelGeometryArrayArchive)

SpecListStyleListLabelTypeArrayArchive = _reflection.GeneratedProtocolMessageType('SpecListStyleListLabelTypeArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLISTSTYLELISTLABELTYPEARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecListStyleListLabelTypeArrayArchive)
  ))
_sym_db.RegisterMessage(SpecListStyleListLabelTypeArrayArchive)

SpecListStyleListNumberTypeArrayArchive = _reflection.GeneratedProtocolMessageType('SpecListStyleListNumberTypeArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLISTSTYLELISTNUMBERTYPEARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecListStyleListNumberTypeArrayArchive)
  ))
_sym_db.RegisterMessage(SpecListStyleListNumberTypeArrayArchive)

SpecListStyleStringArrayArchive = _reflection.GeneratedProtocolMessageType('SpecListStyleStringArrayArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECLISTSTYLESTRINGARRAYARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecListStyleStringArrayArchive)
  ))
_sym_db.RegisterMessage(SpecListStyleStringArrayArchive)

SpecPaddingArchive = _reflection.GeneratedProtocolMessageType('SpecPaddingArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECPADDINGARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecPaddingArchive)
  ))
_sym_db.RegisterMessage(SpecPaddingArchive)

SpecParagraphStyleArchive = _reflection.GeneratedProtocolMessageType('SpecParagraphStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECPARAGRAPHSTYLEARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecParagraphStyleArchive)
  ))
_sym_db.RegisterMessage(SpecParagraphStyleArchive)

SpecRuleOffsetArchive = _reflection.GeneratedProtocolMessageType('SpecRuleOffsetArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECRULEOFFSETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecRuleOffsetArchive)
  ))
_sym_db.RegisterMessage(SpecRuleOffsetArchive)

SpecTabsArchive = _reflection.GeneratedProtocolMessageType('SpecTabsArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECTABSARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SpecTabsArchive)
  ))
_sym_db.RegisterMessage(SpecTabsArchive)

CharacterStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('CharacterStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARACTERSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.CharacterStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(CharacterStylePropertyChangeSetArchive)

ColumnStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ColumnStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ColumnStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ColumnStylePropertyChangeSetArchive)

DropCapSpecificStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('DropCapSpecificStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _DROPCAPSPECIFICSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.DropCapSpecificStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(DropCapSpecificStylePropertyChangeSetArchive)

DropCapStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('DropCapStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _DROPCAPSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.DropCapStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(DropCapStylePropertyChangeSetArchive)

ListStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ListStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _LISTSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ListStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ListStylePropertyChangeSetArchive)

ParagraphSpecificStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ParagraphSpecificStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _PARAGRAPHSPECIFICSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ParagraphSpecificStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ParagraphSpecificStylePropertyChangeSetArchive)

ParagraphStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ParagraphStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ParagraphStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ParagraphStylePropertyChangeSetArchive)

ShapeStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ShapeStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ShapeStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ShapeStylePropertyChangeSetArchive)

TOCEntryStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('TOCEntryStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _TOCENTRYSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCEntryStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(TOCEntryStylePropertyChangeSetArchive)

StyleDiffArchive = _reflection.GeneratedProtocolMessageType('StyleDiffArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEDIFFARCHIVE,
  __module__ = 'TSWPArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StyleDiffArchive)
  ))
_sym_db.RegisterMessage(StyleDiffArchive)


# @@protoc_insertion_point(module_scope)
